@@ -3,6 +3,19 @@ import sys
 
 sys.path.insert(0, os.path.abspath('../..'))
 
+extensions = [
+    'sphinx.ext.autodoc',
+    'openstackdocstheme',
+    'reno.sphinxext'
+]
+
+# openstackdocstheme options
+repository_name = 'openstack/shade'
+bug_project = '760'
+bug_tag = ''
+html_last_updated_fmt = '%Y-%m-%d %H:%M'
+html_theme = 'openstackdocs'
+
 # The suffix of source filenames.
 source_suffix = '.rst'
 
